@@ -8,6 +8,9 @@ module Bogus
     def_delegators :context, :before, :after, :described_class
 
     def described_class=(value)
+      # for new RSpec (> 3.0)
+      context.metadata[:described_class] = value
+      # for old RSpec (< 3.0)
       context.example.metadata[:example_group][:described_class] = value
     end
 
