@@ -1,13 +1,15 @@
 require 'spec_helper'
 
-if RUBY_VERSION >= '2.1'
+if RubyFeatures.required_keyword_arguments?
   describe "Ruby 2.1 required keyword arguments" do
     class ExampleForRequiredKeywordArgs
       eval "def foo(x:); end"
       eval "def bar(x:, **rest); end"
     end
 
-    include Bogus::MockingDSL
+    before do
+      extend Bogus::MockingDSL
+    end
 
     context "with regular objects" do
       subject { ExampleForRequiredKeywordArgs.new }
