@@ -1,13 +1,15 @@
 require 'spec_helper'
 
-if RUBY_VERSION >= '2.0'
+if RubyFeatures.keyword_arguments?
   describe "Ruby 2.0 keyword arguments" do
     class ExampleForKeywordArgs
       eval "def foo(x: 1); end"
       eval "def bar(x: 1, **rest); end"
     end
 
-    include Bogus::MockingDSL
+    before do
+      extend Bogus::MockingDSL
+    end
 
     context "with regular objects" do
       subject { ExampleForKeywordArgs.new }
