@@ -1,14 +1,14 @@
 require 'simplecov'
 begin
   require "coveralls"
+  SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
+    SimpleCov::Formatter::HTMLFormatter,
+    Coveralls::SimpleCov::Formatter]
 rescue LoadError
   warn "warning: coveralls gem not found; skipping Coveralls"
+  SimpleCov.formatter = SimpleCov::Formatter::HTMLFormatter
 end
 
-SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
-  SimpleCov::Formatter::HTMLFormatter,
-  Coveralls::SimpleCov::Formatter]
-
 SimpleCov.start do
   add_filter "/spec/"
 end
@@ -16,19 +16,12 @@ end
 require 'bogus'
 require 'dependor/rspec'
 
-require 'rr'
-
 require_relative 'support/sample_fake'
 require_relative 'support/fake_creator_of_fakes'
 require_relative 'support/matchers'
 require_relative 'support/shared_examples_for_keyword_arguments'
+require_relative 'support/ruby_features'
 
 RSpec.configure do |config|
-  config.color_enabled = true
-  config.mock_framework = :rr
-end
-
-# this should not be necessary...
-def have_received(method = nil)
-  RR::Adapters::Rspec::InvocationMatcher.new(method)
+  config.mock_with :rspec
 end
